diff --git a/core/lib/Drupal/Core/Extension/InfoParserInterface.php b/core/lib/Drupal/Core/Extension/InfoParserInterface.php
index 2c6e2d1..8f7906e 100644
--- a/core/lib/Drupal/Core/Extension/InfoParserInterface.php
+++ b/core/lib/Drupal/Core/Extension/InfoParserInterface.php
@@ -27,7 +27,11 @@
    * - type: whether it is for a module or theme. (Required)
    *
    * Information stored in a module .info.yml file:
-   * - dependencies: An array of shortnames of other modules this module requires.
+   * - dependencies: An array of strings of the form project:module (>x.y).
+   *   - project: Project shortname. (Recommended to ensure uniqueness)
+   *   - module: Module shortname within the project. (Required)
+   *   - (>x.y): Version requirement with operator and version. (Optional)
+   *   Example: drupal:system (>=7.22)
    * - package: The name of the package of modules this module belongs to.
    *
    * See forum.info.yml for an example of a module .info.yml file.
diff --git a/core/modules/system/css/system.admin.css b/core/modules/system/css/system.admin.css
index a4024f4..54310e2 100644
--- a/core/modules/system/css/system.admin.css
+++ b/core/modules/system/css/system.admin.css
@@ -136,6 +136,9 @@ span.admin-enabled {
 span.admin-missing {
   color: #f00;
 }
+span.admin-warning {
+  color: #fb0;
+}
 a.module-link {
   display: block;
   padding: 2px 20px;
diff --git a/core/modules/system/src/Form/ModulesListForm.php b/core/modules/system/src/Form/ModulesListForm.php
index b12c4d2..600a211 100644
--- a/core/modules/system/src/Form/ModulesListForm.php
+++ b/core/modules/system/src/Form/ModulesListForm.php
@@ -24,6 +24,7 @@
 use Drupal\Core\Session\AccountInterface;
 use Symfony\Component\DependencyInjection\ContainerInterface;
 use Symfony\Component\HttpFoundation\Request;
+use Drupal\Component\Utility\Xss;
 
 /**
  * Provides module installation interface.
@@ -356,35 +357,61 @@ protected function buildRow(array $modules, Extension $module, $distribution) {
 
     // If this module requires other modules, add them to the array.
     foreach ($module->requires as $dependency => $version) {
-      if (!isset($modules[$dependency])) {
-        $row['#requires'][$dependency] = $this->t('@module (<span class="admin-missing">missing</span>)', array('@module' => Unicode::ucfirst($dependency)));
+      // Split out the optional project name.
+      if (strpos($dependency, ':')) {
+        list($project_name, $module_name) = explode(':', $dependency);
+        $project = l(Unicode::ucfirst($project_name), 'https://drupal.org/project/' . $project_name) . ':';
+      }
+      else {
+        $module_name = $dependency;
+        unset($project_name);
+        $project = '';
+      }
+      if (!isset($modules[$module_name])) {
+        $row['#requires'][$module_name] = $this->t('!module (<span class="admin-missing">missing</span>)', array('!module' => Xss::filter($project . Unicode::ucfirst($module_name))));
         $row['enable']['#disabled'] = TRUE;
       }
       // Only display visible modules.
-      elseif (empty($modules[$dependency]->hidden)) {
-        $name = $modules[$dependency]->info['name'];
+      elseif (empty($modules[$module_name]->hidden)) {
+        if (isset($project_name)) {
+          $project = l(Unicode::ucfirst($project_name), 'https://drupal.org/project/' . $project_name);
+          $name = $project . ':' . $modules[$module_name]->info['name'];
+        }
+        else {
+          $name = $modules[$module_name]->info['name'];
+        }
         // Disable the module's checkbox if it is incompatible with the
         // dependency's version.
         if ($incompatible_version = drupal_check_incompatibility($version, str_replace(\Drupal::CORE_COMPATIBILITY . '-', '', $modules[$dependency]->info['version']))) {
-          $row['#requires'][$dependency] = $this->t('@module (<span class="admin-missing">incompatible with</span> version @version)', array(
-            '@module' => $name . $incompatible_version,
-            '@version' => $modules[$dependency]->info['version'],
+          $row['#requires'][$module_name] = $this->t('!module (<span class="admin-missing">incompatible with</span> version @version)', array(
+            '!module' => Xss::filter($name . $incompatible_version),
+            '@version' => $modules[$module_name]->info['version'],
           ));
           $row['enable']['#disabled'] = TRUE;
         }
         // Disable the checkbox if the dependency is incompatible with this
         // version of Drupal core.
-        elseif ($modules[$dependency]->info['core'] != \Drupal::CORE_COMPATIBILITY) {
-          $row['#requires'][$dependency] = $this->t('@module (<span class="admin-missing">incompatible with</span> this version of Drupal core)', array(
-            '@module' => $name,
+        elseif ($modules[$module_name]->info['core'] != \Drupal::CORE_COMPATIBILITY) {
+          $row['#requires'][$module_name] = $this->t('!module (<span class="admin-missing">incompatible with</span> this version of Drupal core)', array(
+            '!module' => Xss::filter($name),
           ));
           $row['enable']['#disabled'] = TRUE;
         }
-        elseif ($modules[$dependency]->status) {
-          $row['#requires'][$dependency] = $this->t('@module', array('@module' => $name));
+        elseif ($modules[$module_name]->status) {
+          if (isset($project_name) &&
+            isset($modules[$module_name]->info['project']) &&
+            $project_name != $modules[$module_name]->info['project']) {
+
+            $row['#requires'][$module_name]
+              = $this->t('!module (<span class="admin-warning">mismatch</span>)', array('!module' => Xss::filter($name)));
+          }
+          else {
+            $row['#requires'][$module_name]
+              = $this->t('!module', array('!module' => Xss::filter($name)));
+          }
         }
         else {
-          $row['#requires'][$dependency] = $this->t('@module (<span class="admin-disabled">disabled</span>)', array('@module' => $name));
+          $row['#requires'][$module_name] = $this->t('!module (<span class="admin-disabled">disabled</span>)', array('!module' => Xss::filter($name)));
         }
       }
     }
diff --git a/core/modules/system/system.install b/core/modules/system/system.install
index f93927e..f35adfd 100644
--- a/core/modules/system/system.install
+++ b/core/modules/system/system.install
@@ -489,7 +489,7 @@ function system_requirements($phase) {
       }
       // Check the module's required modules.
       foreach ($file->requires as $requirement) {
-        $required_module = $requirement['name'];
+        $required_module = $requirement['module'];
         // Check if the module exists.
         if (!isset($files[$required_module])) {
           $requirements["$module-$required_module"] = array(
diff --git a/core/tests/Drupal/Tests/Core/Extension/ModuleHandlerTest.php b/core/tests/Drupal/Tests/Core/Extension/ModuleHandlerTest.php
index bc5da97..62ff673 100644
--- a/core/tests/Drupal/Tests/Core/Extension/ModuleHandlerTest.php
+++ b/core/tests/Drupal/Tests/Core/Extension/ModuleHandlerTest.php
@@ -481,21 +481,22 @@ public function testDependencyParsing($dependency, $expected) {
    */
   public function dependencyProvider() {
     return array(
-      array('system', array('name' => 'system')),
-      array('taxonomy', array('name' => 'taxonomy')),
-      array('views', array('name' => 'views')),
-      array('views_ui(8.x-1.0)', array('name' => 'views_ui', 'original_version' => ' (8.x-1.0)', 'versions' => array(array('op' => '=', 'version' => '1.0')))),
+      array('system', array('module' => 'system')),
+      array('taxonomy', array('module' => 'taxonomy')),
+      array('views', array('module' => 'views')),
+      array('views_ui(8.x-1.0)', array('module' => 'views_ui', 'original_version' => ' (8.x-1.0)', 'versions' => array(array('op' => '=', 'version' => '1.0')))),
       // Not supported?.
       // array('views_ui(8.x-1.1-beta)', array('name' => 'views_ui', 'original_version' => ' (8.x-1.1-beta)', 'versions' => array(array('op' => '=', 'version' => '1.1-beta')))),
-      array('views_ui(8.x-1.1-alpha12)', array('name' => 'views_ui', 'original_version' => ' (8.x-1.1-alpha12)', 'versions' => array(array('op' => '=', 'version' => '1.1-alpha12')))),
-      array('views_ui(8.x-1.1-beta8)', array('name' => 'views_ui', 'original_version' => ' (8.x-1.1-beta8)', 'versions' => array(array('op' => '=', 'version' => '1.1-beta8')))),
-      array('views_ui(8.x-1.1-rc11)', array('name' => 'views_ui', 'original_version' => ' (8.x-1.1-rc11)', 'versions' => array(array('op' => '=', 'version' => '1.1-rc11')))),
-      array('views_ui(8.x-1.12)', array('name' => 'views_ui', 'original_version' => ' (8.x-1.12)', 'versions' => array(array('op' => '=', 'version' => '1.12')))),
-      array('views_ui(8.x-1.x)', array('name' => 'views_ui', 'original_version' => ' (8.x-1.x)', 'versions' => array(array('op' => '<', 'version' => '2.x'), array('op' => '>=', 'version' => '1.x')))),
-      array('views_ui( <= 8.x-1.x)', array('name' => 'views_ui', 'original_version' => ' ( <= 8.x-1.x)', 'versions' => array(array('op' => '<=', 'version' => '2.x')))),
-      array('views_ui(<= 8.x-1.x)', array('name' => 'views_ui', 'original_version' => ' (<= 8.x-1.x)', 'versions' => array(array('op' => '<=', 'version' => '2.x')))),
-      array('views_ui( <=8.x-1.x)', array('name' => 'views_ui', 'original_version' => ' ( <=8.x-1.x)', 'versions' => array(array('op' => '<=', 'version' => '2.x')))),
-      array('views_ui(>8.x-1.x)', array('name' => 'views_ui', 'original_version' => ' (>8.x-1.x)', 'versions' => array(array('op' => '>', 'version' => '2.x')))),
+      array('views_ui(8.x-1.1-alpha12)', array('module' => 'views_ui', 'original_version' => ' (8.x-1.1-alpha12)', 'versions' => array(array('op' => '=', 'version' => '1.1-alpha12')))),
+      array('views_ui(8.x-1.1-beta8)', array('module' => 'views_ui', 'original_version' => ' (8.x-1.1-beta8)', 'versions' => array(array('op' => '=', 'version' => '1.1-beta8')))),
+      array('views_ui(8.x-1.1-rc11)', array('module' => 'views_ui', 'original_version' => ' (8.x-1.1-rc11)', 'versions' => array(array('op' => '=', 'version' => '1.1-rc11')))),
+      array('views_ui(8.x-1.12)', array('module' => 'views_ui', 'original_version' => ' (8.x-1.12)', 'versions' => array(array('op' => '=', 'version' => '1.12')))),
+      array('views_ui(8.x-1.x)', array('module' => 'views_ui', 'original_version' => ' (8.x-1.x)', 'versions' => array(array('op' => '<', 'version' => '2.x'), array('op' => '>=', 'version' => '1.x')))),
+      array('views_ui( <= 8.x-1.x)', array('module' => 'views_ui', 'original_version' => ' ( <= 8.x-1.x)', 'versions' => array(array('op' => '<=', 'version' => '2.x')))),
+      array('views_ui(<= 8.x-1.x)', array('module' => 'views_ui', 'original_version' => ' (<= 8.x-1.x)', 'versions' => array(array('op' => '<=', 'version' => '2.x')))),
+      array('views_ui( <=8.x-1.x)', array('module' => 'views_ui', 'original_version' => ' ( <=8.x-1.x)', 'versions' => array(array('op' => '<=', 'version' => '2.x')))),
+      array('views_ui(>8.x-1.x)', array('module' => 'views_ui', 'original_version' => ' (>8.x-1.x)', 'versions' => array(array('op' => '>', 'version' => '2.x')))),
+      array('drupal:views_ui(>8.x-1.x)', array('project' => 'drupal', 'module' => 'views_ui', 'original_version' => ' (>8.x-1.x)', 'versions' => array(array('op' => '>', 'version' => '2.x')))),
     );
   }
 

diff --git a/core/lib/Drupal/Core/Extension/ModuleHandler.php b/core/lib/Drupal/Core/Extension/ModuleHandler.php
index 6270c8e..bdf1f04 100644
--- a/core/lib/Drupal/Core/Extension/ModuleHandler.php
+++ b/core/lib/Drupal/Core/Extension/ModuleHandler.php
@@ -217,7 +217,14 @@ public function buildModuleDependencies(array $modules) {
       if (isset($module->info['dependencies']) && is_array($module->info['dependencies'])) {
         foreach ($module->info['dependencies'] as $dependency) {
           $dependency_data = static::parseDependency($dependency);
-          $graph[$module->getName()]['edges'][$dependency_data['name']] = $dependency_data;
+          if (isset($dependency_data['project'])) {
+            $key = $dependency_data['project'] . ':' .
+              $dependency_data['module'];
+          }
+          else {
+            $key = $dependency_data['module'];
+          }
+          $graph[$module->getName()]['edges'][$key] = $dependency_data;
         }
       }
     }
@@ -649,7 +656,7 @@ protected function verifyImplementations(&$implementations, $hook) {
    * Parses a dependency for comparison by drupal_check_incompatibility().
    *
    * @param $dependency
    *   A dependency string, for example 'foo (>=8.x-4.5-beta5, 3.x)'.
    *
    * @return
    *   An associative array with three keys:
@@ -664,6 +671,12 @@ protected function verifyImplementations(&$implementations, $hook) {
    * @see drupal_check_incompatibility()
    */
   public static function parseDependency($dependency) {
+    $value = array();
+    // Split out the optional project name.
+    if (strpos($dependency, ':')) {
+      list($project_name, $dependency) = explode(':', $dependency);
+      $value['project'] = $project_name;
+    }
     // We use named subpatterns and support every op that version_compare
     // supports. Also, op is optional and defaults to equals.
     $p_op = '(?<operation>!=|==|=|<|<=|>|>=|<>)?';
@@ -672,9 +685,8 @@ public static function parseDependency($dependency) {
     $p_major = '(?<major>\d+)';
     // By setting the minor version to x, branches can be matched.
     $p_minor = '(?<minor>(?:\d+|x)(?:-[A-Za-z]+\d+)?)';
-    $value = array();
     $parts = explode('(', $dependency, 2);
-    $value['name'] = trim($parts[0]);
+    $value['module'] = trim($parts[0]);
     if (isset($parts[1])) {
       $value['original_version'] = ' (' . $parts[1];
       foreach (explode(',', $parts[1]) as $version) {
@@ -649,7 +656,7 @@ protected function verifyImplementations(&$implementations, $hook) {
    *
    * @param $dependency
-   *   A dependency string, for example 'foo (>=8.x-4.5-beta5, 3.x)'.
+   *   A dependency string, for example 'project:module (>=8.x-4.5-beta5, 3.x)'.
    *
    * @return